#ifndef NT2_INCLUDE_FUNCTIONS_RREF_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_RREF_HPP_INCLUDED

#include <nt2/linalg/include/functions/rref.hpp>

#endif
